.. _debops-contrib.x2go_server:

Ansible role: debops-contrib.x2go_server
========================================

.. toctree::
   :maxdepth: 2

   introduction
   getting-started
   defaults
   copyright
   changelog

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
